==> warcar-web-demo-2.2.1.1-sources.jar: com/bxm/warcar/web/demo/SpringApplicationRunListener2.java <==
package com.bxm.warcar.web.demo;

import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.env.ConfigurableEnvironment;

import java.util.concurrent.TimeUnit;

/**
 * @author allen
 * @since 2020-03-17
 */
@Slf4j
public class SpringApplicationRunListener2 implements SpringApplicationRunListener {

    public SpringApplicationRunListener2(SpringApplication springApplication, String[] args) {
        log.info("-----construct");
    }

    @Override
    public void starting() {
        log.info("-----starting");
    }

    @Override
    public void environmentPrepared(ConfigurableEnvironment environment) {
        log.info("-----environmentPrepared");
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {
        log.info("-----contextPrepared");
    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {
        log.info("-----contextLoaded");
    }

    @Override
    public void started(ConfigurableApplicationContext context) {
        log.info("-----started");
    }

    @Override
    public void running(ConfigurableApplicationContext context) {
        log.info("-----running");
    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
        log.info("-----failed");
    }
}

==> warcar-web-demo-2.2.5.4-sources.jar: com/bxm/warcar/web/demo/SpringApplicationRunListener2.java <==
package com.bxm.warcar.web.demo;

import com.bxm.warcar.web.demo.customizer.CustomizerEvent;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.env.ConfigurableEnvironment;

import java.util.concurrent.TimeUnit;

/**
 * @author allen
 * @since 2020-03-17
 */
@Slf4j
public class SpringApplicationRunListener2 implements SpringApplicationRunListener {

    public SpringApplicationRunListener2(SpringApplication springApplication, String[] args) {
        log.info("-----construct");
    }

    @Override
    public void starting() {
        log.info("-----starting");
    }

    @Override
    public void environmentPrepared(ConfigurableEnvironment environment) {
        log.info("-----environmentPrepared");
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {
        log.info("-----contextPrepared");
    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {
        log.info("-----contextLoaded");
    }

    @Override
    public void started(ConfigurableApplicationContext context) {
        log.info("-----started");
    }

    @Override
    public void running(ConfigurableApplicationContext context) {
        log.info("-----running");

        context.publishEvent(new CustomizerEvent(this));
        log.info("publish event finished!");
    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
        log.info("-----failed");
    }
}
